%{!?cmake_build:%define cmake_build %{make_build}}
%{!?cmake_install:%define cmake_install %{make_install}}

Name:           i2pd
Version:        2.56.0
Release:        2%{?dist}.1
Summary:        I2P router written in C++

License:        BSD
URL:            https://github.com/PurpleI2P/i2pd
Source0:        https://github.com/PurpleI2P/i2pd/archive/%{version}/%name-%version.tar.gz
Source1:        i2pd.service

BuildRequires:  cmake >= 3.7
BuildRequires:  gcc-c++
BuildRequires:  zlib-devel
BuildRequires:  boost-devel
BuildRequires:  openssl-devel
BuildRequires:  miniupnpc-devel
BuildRequires:  systemd-units

Requires:       logrotate
Requires:       systemd
Requires(pre):  %{_sbindir}/useradd %{_sbindir}/groupadd

Provides:       %{name}-daemon = %{?epoch?%{epoch}:}%{version}-%{release}
Provides:       %{name}-systemd = %{?epoch?%{epoch}:}%{version}-%{release}
Obsoletes:      %{name}-daemon
Obsoletes:      %{name}-systemd


%description
C++ implementation of I2P.


%prep
%setup -q


%build
cd build
%cmake \
    -DWITH_LIBRARY=OFF \
    -DWITH_UPNP=ON \
    -DWITH_HARDENING=ON \
    -DBUILD_SHARED_LIBS:BOOL=OFF \
    -DCMAKE_SKIP_RPATH:BOOL=ON \
    -DCMAKE_INSTALL_BINDIR:STRING=%(s=%{_sbindir}; echo ${s##*/})

%cmake_build


%install
pushd build
%cmake_install
popd
install -d -m 755 %{buildroot}%{_datadir}/i2pd
install -d -m 755 %{buildroot}%{_datadir}/i2pd/tunnels.conf.d
install -d -m 700 %{buildroot}%{_sharedstatedir}/i2pd
install -d -m 700 %{buildroot}%{_localstatedir}/log/i2pd
install -D -m 644 contrib/i2pd.conf %{buildroot}%{_sysconfdir}/i2pd/i2pd.conf
install -D -m 644 contrib/subscriptions.txt %{buildroot}%{_sysconfdir}/i2pd/subscriptions.txt
install -D -m 644 contrib/tunnels.conf %{buildroot}%{_sysconfdir}/i2pd/tunnels.conf
install -D -m 644 contrib/i2pd.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/i2pd
install -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/i2pd.service
install -D -m 644 debian/i2pd.1 %{buildroot}%{_mandir}/man1/i2pd.1
cp -r contrib/certificates/ %{buildroot}%{_datadir}/i2pd/certificates
cp -r contrib/tunnels.d/ %{buildroot}%{_sysconfdir}/i2pd/tunnels.conf.d
ln -s %{_datadir}/%{name}/certificates %{buildroot}%{_sharedstatedir}/i2pd/certificates


%pre
getent group i2pd >/dev/null || %{_sbindir}/groupadd -r i2pd
getent passwd i2pd >/dev/null || \
  %{_sbindir}/useradd -r -g i2pd -s %{_sbindir}/nologin \
                      -d %{_sharedstatedir}/i2pd -c 'I2P Service' i2pd


%post
%systemd_post i2pd.service


%preun
%systemd_preun i2pd.service


%postun
%systemd_postun_with_restart i2pd.service


%triggerun -- %{name}-systemd < 2.23.0
# Move config files from old version to proper place
for f in i2pd.conf tunnels.conf; do
  if [ -f "%{_sharedstatedir}/i2pd/$f" -a ! -f "%{_sysconfdir}/i2pd/$f" ]; then
    %{__mv} "%{_sharedstatedir}/i2pd/$f" "%{_sysconfdir}/i2pd/$f"
  fi
done


%files
%license LICENSE
%doc README.md contrib/i2pd.conf contrib/subscriptions.txt contrib/tunnels.conf contrib/tunnels.d
%{_sbindir}/i2pd
%{_datadir}/i2pd
%{_mandir}/man1/i2pd.1*
%dir %attr(0750,root,i2pd) %{_sysconfdir}/i2pd
%dir %attr(0750,root,i2pd) %{_sysconfdir}/i2pd/tunnels.conf.d
%config(noreplace) %{_sysconfdir}/i2pd/*.conf
%config(noreplace) %{_sysconfdir}/i2pd/tunnels.conf.d/*.conf
%{_sysconfdir}/i2pd/tunnels.conf.d/README
%{_sysconfdir}/i2pd/subscriptions.txt
%{_unitdir}/i2pd.service
%dir %attr(0700,i2pd,i2pd) %{_sharedstatedir}/i2pd
%dir %attr(0700,i2pd,i2pd) %{_localstatedir}/log/i2pd
%{_sharedstatedir}/i2pd/certificates
%{_sysconfdir}/logrotate.d/i2pd
%changelog
* Thu Mar 27 2025 Oleg Girko <ol@infoserver.lv> - 2.56.0-2
- Don't rely on %%{_sbindir} to always be "/usr/sbin"
* Fri Mar  7 2025 Oleg Girko <ol@infoserver.lv> - 2.56.0-1
- update to 2.56.0
* Mon Feb  3 2025 Oleg Girko <ol@infoserver.lv> - 2.55.0-1
- update to 2.55.0
* Fri Oct 11 2024 Oleg Girko <ol@infoserver.lv> - 2.54.0-1
- update to 2.54.0
* Sun Aug  4 2024 Oleg Girko <ol@infoserver.lv> - 2.53.1-1
- update to 2.53.1
* Sat Jul 20 2024 Oleg Girko <ol@infoserver.lv> - 2.53.0-1
- update to 2.53.0
* Tue May 21 2024 Oleg Girko <ol@infoserver.lv> - 2.52.0-1
- update to 2.52.0
* Tue Apr  9 2024 Oleg Girko <ol@infoserver.lv> - 2.51.0-1
- update to 2.51.0
* Wed Jan 17 2024 Oleg Girko <ol@infoserver.lv> - 2.50.2-1
- update to 2.50.2
* Mon Dec 18 2023 Oleg Girko <ol@infoserver.lv> - 2.50.0-1
- update to 2.50.0
* Fri Sep 22 2023 Oleg Girko <ol@infoserver.lv> - 2.49.0-1
- update to 2.49.0
* Fri Jun 16 2023 Oleg Girko <ol@infoserver.lv> - 2.48.0-1
- update to 2.48.0
* Sun Mar 26 2023 Oleg Girko <ol@infoserver.lv> - 2.47.0-1
- update to 2.47.0
* Sat Feb 25 2023 Oleg Girko <ol@infoserver.lv> - 2.46.1-1
- update to 2.46.1
* Thu Jan 12 2023 Oleg Girko <ol@infoserver.lv> - 2.45.1-1
- update to 2.45.1
* Fri Jan  6 2023 Oleg Girko <ol@infoserver.lv> - 2.45.0-1
- update to 2.45.0
* Fri Dec  9 2022 Oleg Girko <ol@infoserver.lv> - 2.44.0-1
- update to 2.44.0
* Mon Aug 29 2022 Oleg Girko <ol@infoserver.lv> - 2.43.0-1
- update to 2.43.0
* Mon Jun  6 2022 Oleg Girko <ol@infoserver.lv> - 2.42.1-1
- update to 2.42.1
* Mon Feb 21 2022 Oleg Girko <ol@infoserver.lv> - 2.41.0-1
- update to 2.41.0
* Fri Dec  3 2021 Oleg Girko <ol@infoserver.lv> - 2.40.0-1
- update to 2.40.0
- remove cmake3 workarounds (CentOS 7 build works without them)
* Tue Nov 23 2021 Oleg Girko <ol@infoserver.lv> - 2.39.0-4
- fix a typo in %%cmake3 workaround macro definition
* Wed Nov 17 2021 Oleg Girko <ol@infoserver.lv> - 2.39.0-3
- move cmake3 workarounds to be placed in the beginning of spec file
- install i2pd binary using cmake
- merge systemd subpackage into the main package
- move config files from old version to proper place using %%triggerun
- use %%license for LICENSE file
* Mon Aug 23 2021 Oleg Girko <ol@infoserver.lv> - 2.39.0-2
- use CMAKE_SKIP_RPATH cmake variable instead of removing rpath explicitly
- always require cmake3 for build: it should work for CentOS and Fedora
- use install, cp and ln commands instead os macros with double underscore
- don't change directory to install just i2pd binary, specify its path instead
- recommend systemd subpackage is Recommends is supported
* Mon Aug 23 2021 Oleg Girko <ol@infoserver.lv> - 2.39.0-1
- update to 2.39.0
* Sat May 22 2021 Oleg Girko <ol@infoserver.lv> - 2.38.0-1
- update to 2.38.0
* Sat Mar 20 2021 Oleg Girko <ol@infoserver.lv> - 2.37.0-1
- update to 2.37.0
- use SIGTERM for terminating service
* Tue Feb 16 2021 Oleg Girko <ol@infoserver.lv> - 2.36.0-1
- update to 2.36.0
* Mon Nov 30 2020 Oleg Girko <ol@infoserver.lv> - 2.35.0-1
- update to 2.35.0
* Fri Oct 30 2020 Oleg Girko <ol@infoserver.lv> - 2.34.0-1
- update to 2.34.0
* Thu Oct 29 2020 Oleg Girko <ol@infoserver.lv> - 2.33.0-2
- use proper macros to build and install
* Mon Aug 24 2020 Oleg Girko <ol@infoserver.lv> - 2.33.0-1
- update to 2.33.0
* Thu Jun  4 2020 Oleg Girko <ol@infoserver.lv> - 2.32.1-1
- update to 2.32.1
- use our systemd service file instead of the one from contrib directory
* Mon May 25 2020 Oleg Girko <ol@infoserver.lv> - 2.32.0-1
- update to 2.32.0
- partially sync spec file with upstream
* Sat Apr 11 2020 Oleg Girko <ol@infoserver.lv> - 2.31.0-1
- update to 2.31.0
* Tue Feb 25 2020 Oleg Girko <ol@infoserver.lv> - 2.30.0-1
- update to 2.30.0
* Mon Oct 21 2019 Oleg Girko <ol@infoserver.lv> - 2.29.0-1
- update to 2.29.0
* Sat Aug 31 2019 Oleg Girko <ol@infoserver.lv> - 2.28.0-1
- update to 2.28.0
* Fri Jul  5 2019 Oleg Girko <ol@infoserver.lv> - 2.27.0-1
- update to 2.27.0
* Fri Jun  7 2019 Oleg Girko <ol@infoserver.lv> - 2.26.0-1
- update to 2.26.0
* Mon May 13 2019 Oleg Girko <ol@infoserver.lv> - 2.25.0-1
- update to 2.25.0
* Fri Mar 22 2019 Oleg Girko <ol@infoserver.lv> - 2.24.0-1
- update to 2.24.0
* Tue Jan 22 2019 Oleg Girko <ol@infoserver.lv> - 2.23.0-1
- update to 2.23.0
* Sun Dec  9 2018 Oleg Girko <ol@infoserver.lv> - 2.22.0-2
- add support for RHEL7/CentOS7
- use systemd service file from contrib directory
- install i2pd into /usr/sbin
- install certificates and default configuration files
- require systemd-units for build
- make i2pd-systemd package noarch
- install man page
* Fri Nov  9 2018 Oleg Girko <ol@infoserver.lv> - 2.22.0-1
- update to 2.22.0
* Tue Oct 23 2018 Oleg Girko <ol@infoserver.lv> - 2.21.1-1
- update to 2.21.1
* Fri Oct  5 2018 Oleg Girko <ol@infoserver.lv> - 2.21.0-1
- update to 2.21.0
* Thu Aug 23 2018 Oleg Girko <ol@infoserver.lv> - 2.20.0-1
- update to 2.20.0
* Tue Jun 26 2018 Oleg Girko <ol@infoserver.lv> - 2.19.0-1
- update to 2.19.0
* Tue May  1 2018 Oleg Girko <ol@infoserver.lv> - 2.18.0-2
- add patch to fix build with GCC 8 in Fedora 28
* Tue Jan 30 2018 Oleg Girko <ol@infoserver.lv> - 2.18.0-1
- update to 2.18.0
* Mon Dec  4 2017 Oleg Girko <ol@infoserver.lv> - 2.17.0-1
- update to 2.17.0
* Sat Nov 18 2017 Oleg Girko <ol@infoserver.lv> - 2.16.0-1
- update to 2.16.0
* Sat Aug 19 2017 Oleg Girko <ol@infoserver.lv> - 2.15.0-1
- update to 2.15.0
* Thu Jun  1 2017 Oleg Girko <ol@infoserver.lv> - 2.14.0-1
- update to 2.14.0
* Fri Apr  7 2017 Oleg Girko <ol@infoserver.lv> - 2.13.0-1
- update to 2.13.0
* Tue Feb 14 2017 Oleg Girko <ol@infoserver.lv> - 2.12.0-1
- update to 2.12.0
* Tue Dec 20 2016 Oleg Girko <ol@infoserver.lv> - 2.11.0-1
- update to 2.11.0
- provide reload feature in systemd unit file
* Sun Dec  4 2016 Oleg Girko <ol@infoserver.lv> - 2.10.2-1
- update to 2.10.2
* Mon Nov  7 2016 Oleg Girko <ol@infoserver.lv> - 2.10.1-1
- update to 2.10.1
* Sun Oct 16 2016 Oleg Girko <ol@infoserver.lv> - 2.10.0-1
- update to 2.10.0
* Sun Aug 14 2016 Oleg Girko <ol@infoserver.lv> - 2.9.0-1
- update to 2.9.0
* Sun Aug  7 2016 Oleg Girko <ol@infoserver.lv> - 2.8.0-2
- rename daemon subpackage to systemd
* Sat Aug  6 2016 Oleg Girko <ol@infoserver.lv> - 2.8.0-1
- update to 2.8.0
- remove wrong rpath from i2pd binary
- add daemon subpackage with systemd unit file
* Sat May 21 2016 Oleg Girko <ol@infoserver.lv> - 2.7.0-1
- update to 2.7.0
* Tue Apr  5 2016 Oleg Girko <ol@infoserver.lv> - 2.6.0-1
- update to 2.6.0
* Tue Jan 26 2016 Yaroslav Sidlovsky <zawertun@gmail.com> - 2.3.0-1
- initial package for version 2.3.0
